# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Config-Tiny
Version:	2.20
Release:	1.%{__distinit}%{__distvers}
Summary:	Perl module for reading and writing .ini style configuration files
Group:		Development/Libraries
License:	GPL+ or Artistic
URL:		http://search.cpan.org/dist/Config-Tiny/
Source0:	http://search.cpan.org/CPAN/authors/id/R/RS/RSAVAGE/Config-Tiny-%{version}.tgz
Source1:	File-Temp-0.21.pm
Patch0:		Config-Tiny-2.20-build-on-old-perl.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# Module Build
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(warnings)
# Module Runtime
BuildRequires:	perl(strict)
# Test Suite
# META.* calls for 3.30 but 0.87 works fine
BuildRequires:	perl(File::Spec) >= 0.87
# META.* calls for 0.22 but 0.19 is the actual requirement, and we bundle a later version if needed
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(Test::More) >= 0.47
BuildRequires:	perl(UNIVERSAL)
BuildRequires:	perl(utf8)
# Extra Tests
BuildRequires:	perl(Test::CPAN::Meta) >= 0.17
# Test::MinimumVersion -> Perl::MinimumVersion -> Perl::Critic -> Config::Tiny
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(Test::MinimumVersion) >= 0.101080
%endif
BuildRequires:	perl(Test::Pod) >= 1.44
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
Config::Tiny is a Perl module designed for reading and writing .ini
style configuration files. It is designed for simplicity and ease of
use, and thus only supports the most basic operations.

%prep
%setup -q -n Config-Tiny-%{version}

# On old perls, we can end up trying to use Module::Build without this fix
%patch0

# File::Temp 0.19 is needed for the newdir method (just for the test suite)
%if %(perl -MFile::Temp -e 'print $File::Temp::VERSION < 0.19 ? 1 : 0;')
mkdir -p inc/File
cp -p %{SOURCE1} inc/File/Temp.pm
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
%{_fixperms} %{buildroot}

%check
# Use our local File::Temp if necessary
[ -f inc/File/Temp.pm ] && export PERL5LIB=$(pwd)/inc

make test
make test TEST_FILES="xt/*.t" AUTOMATED_TESTING=1

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc Changes LICENSE README
%{perl_vendorlib}/Config/
%{_mandir}/man3/Config::Tiny.3pm*

%changelog
* Sun Nov 24 2013 Paul Howarth <paul@city-fan.org> - 2.20-1
- Update to 2.20
  - Relax pre-req version requirements

* Sun Sep 15 2013 Paul Howarth <paul@city-fan.org> - 2.19-1
- Update to 2.19
  - Remove obsolete and wrong version # from Makefile.PL (CPAN RT#88658)
  - Test if read() will return undef; if so, set an error message and (still)
    return undef
  - Change VERSION => $VERSION in Makefile.PL to
    VERSION_FROM => 'lib/Config/Tiny.pm' (CPAN RT#88670)

* Fri Sep 13 2013 Paul Howarth <paul@city-fan.org> - 2.17-1
- Update to 2.17
  - Remove the file tests -efr during calls to read(); the open() tests for any
    error
  - The -f test was reporting /dev/null as a directory, not a file
    (CPAN RT#36974)
  - Clean up some error messages slightly

* Fri Sep  6 2013 Paul Howarth <paul@city-fan.org> - 2.16-1
- Update to 2.16
  - Replace Path::Tiny with File::Spec, because the former's list of
    dependencies is soooo long :-( (see CPAN RT#88435 for Tree::DAG_Node)
- Reinstate support for old distributions back to FC-3
- Use a locally bundled copy of File::Temp for the test suite if necessary,
  as we need the newdir method, which is only available from version 0.19
- Add patch to prevent ExtUtils::MakeMaker trying to use Module::Build on old
  distributions

* Mon Sep  2 2013 Paul Howarth <paul@city-fan.org> - 2.15-1
- Update to 2.15
  - Clean up the shambolic dates in the Changes file
  - Add a note under Caveats about setting options more that once - only the
    first case is respected (CPAN RT#69795)
  - Add a $encoding parameter to read_file() and write_file(), and add
    t/04.utf8.t and t/04.utf8.txt (CPAN RT#71029, CPAN RT#85571)
  - Fix temporary directory creation in tests for BSD-based systems
  - Rename t/*.t files
  - Add MANIFEST.SKIP, Changelog.ini, Build.PL, META.json
  - Add a FAQ to the docs
  - Clean up the docs
- This release by RSAVAGE -> update source URL
- Specify all dependencies
- Drop support for old rpm versions as we need Path::Tiny, which is not
  available there

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 2.14-5
- Perl 5.16 post-bootstrap rebuild

* Sun Jul  1 2012 Paul Howarth <paul@city-fan.org> - 2.14-4
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Tue Feb  7 2012 Paul Howarth <paul@city-fan.org> - 2.14-3
- Don't BR: perl(Test::MinimumVersion) if we're bootstrapping

* Wed Jun 22 2011 Paul Howarth <paul@city-fan.org> - 2.14-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Mar 24 2011 Paul Howarth <paul@city-fan.org> - 2.14-1
- Update to 2.14:
  - Resolved CPAN RT#63080: module can write multiline values but not read them
  - Removed -w from tests to allow tests with tainting on
- Nobody else likes macros for commands

* Sun Sep  5 2010 Paul Howarth <paul@city-fan.org> - 2.13-1
- Update to 2.13:
  - Fix CPAN RT#30479: should warn or die when writing data it cannot later read
  - Fix CPAN RT#40585: member 'set;' doesn't exist
  - Fix CPAN RT#60703: display glitch in Config::Tiny 2.12 POD
- No longer need to fix file permissions
- Explicitly run additional release tests
- BuildRequires: perl(Test::CPAN::Meta)

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 2.12-10
- Rebuild for perl 5.12.1 in Rawhide

* Tue Jun  8 2010 Paul Howarth <paul@city-fan.org> - 2.12-9
- Fix dist tag for RHEL-6 Beta

* Fri Feb 19 2010 Paul Howarth <paul@city-fan.org> - 2.12-8
- Dist tag for Rawhide no longer needs special-casing
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Thu Sep  3 2009 Paul Howarth <paul@city-fan.org> - 2.12-7
- Define RPM macros in global scope

* Wed Sep  3 2008 Paul Howarth <paul@city-fan.org> - 2.12-6
- Import from Fedora
- Add buildreq perl(ExtUtils::MakeMaker)

* Thu Feb 28 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 2.12-5
- Rebuild normally, second pass

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 2.12-4
- Rebuild for perl 5.10 (again), first pass

* Mon Jan 14 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 2.12-3
- Rebuild normally, second pass

* Sun Jan 13 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 2.12-2.1
- Rebuild with TMV, tests disabled for first pass

* Fri Jan 11 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 2.12-2
- Rebuild for new perl

* Thu Dec 13 2007 Ralf Corsépius <rc040203@freenet.de> - 2.12-1
- Update to 2.12

* Mon Oct  2 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 2.10-1
- Updated to 2.10

* Sun Jul 16 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 2.08-1
- Updated to 2.08

* Wed May 10 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 2.07-1
- Updated to 2.07

* Sat Apr 22 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 2.06-1
- Updated to 2.06

* Mon Mar  6 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 2.05-1
- Updated to 2.05

* Sat Feb 18 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 2.04-2
- Rebuild for FC5 (perl 5.8.8)

* Sat Jan 28 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 2.04-1
- Updated to 2.04

* Fri Dec 30 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 2.03-1
- Updated to 2.03

* Mon Jun 27 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 2.02-1
- Updated to 2.02

* Wed Apr  6 2005 Michael Schwendt <mschwendt[AT]users.sf.net> - 2.01-2
- Rebuilt

* Thu Mar 24 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 2.01-1
- Updated to 2.01

* Sun Jul 25 2004 Marius L. Jøhndal <mariuslj at ifi.uio.no> - 0:2.00-0.fdr.1
- Updated to 2.00

* Sat Jul 10 2004 Marius L. Jøhndal <mariuslj at ifi.uio.no> - 0:1.9-0.fdr.1
- Updated to 1.9

* Fri Jul  2 2004 Marius L. Jøhndal <mariuslj at ifi.uio.no> - 0:1.8-0.fdr.1
- Updated to 1.8

* Tue Jun 29 2004 Marius L. Jøhndal <mariuslj at ifi.uio.no> - 0:1.7-0.fdr.1
- Updated to 1.7

* Sat Jun  5 2004 Marius L. Jøhndal <mariuslj at ifi.uio.no> - 0:1.6-0.fdr.3
- Changed URL to canonical location (bug 1140)
- Added build req perl >= 1:5.6.1 and perl(Test::More) (bug 1140)
- Added missing req perl(:MODULE_COMPAT_...) (bug 1140)
- Updated to match most recent perl spec template (bug 1140)
- Removed unneeded optimization settings and find *.bs (bug 1140)

* Thu Mar 18 2004 Marius L. Jøhndal <mariuslj at ifi.uio.no> - 0:1.6-0.fdr.2
- Reduced directory ownership bloat

* Thu Mar 11 2004 Marius L. Jøhndal <mariuslj at ifi.uio.no> - 0:1.6-0.fdr.1
- Updated to 1.6

* Wed Jan  7 2004 Marius L. Jøhndal <mariuslj at ifi.uio.no> 0:1.5-0.fdr.1
- Updated to 1.5

* Sat Dec 13 2003 Marius L. Jøhndal <mariuslj at ifi.uio.no> 0:1.3-0.fdr.1
- Initial RPM release

